==> rc-ui-lib-2.0.4.tgz: package/es/lazyload/Lazyload.js <==
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import React, { useState, useEffect } from "react";
import { hasIntersectionObserver, modeType } from "./utils";
import LazyloadEvent from "./LazyloadEvent";
import LazyLoadObserve from "./LazyloadObserve";
const Lazyload = (props) => {
  const [mode, setMode] = useState("observer");
  const _a = props, {
    observer,
    eventOptions
  } = _a, resetProps = __objRest(_a, [
    "observer",
    "eventOptions"
  ]);
  useEffect(() => {
    const toSetMode = (value) => {
      if (!hasIntersectionObserver && value === modeType.observer) {
        value = modeType.event;
      }
      setMode(value);
    };
    toSetMode(observer ? modeType.observer : modeType.event);
  }, [observer]);
  return /* @__PURE__ */ React.createElement(React.Fragment, null, mode === modeType.event ? /* @__PURE__ */ React.createElement(LazyloadEvent, _extends({}, resetProps, eventOptions)) : /* @__PURE__ */ React.createElement(LazyLoadObserve, resetProps));
};
Lazyload.defaultProps = {
  loading: null,
  height: 0,
  observer: true
};
var stdin_default = Lazyload;
export {
  stdin_default as default
};

==> rc-ui-lib-2.1.1.tgz: package/es/lazyload/Lazyload.js <==
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import React, { useState, useEffect } from "react";
import { hasIntersectionObserver, modeType } from "./utils";
import LazyloadEvent from "./LazyloadEvent";
import LazyLoadObserve from "./LazyloadObserve";
const Lazyload = (props) => {
  const [mode, setMode] = useState();
  const _a = props, {
    observer,
    eventOptions
  } = _a, resetProps = __objRest(_a, [
    "observer",
    "eventOptions"
  ]);
  useEffect(() => {
    const toSetMode = (value) => {
      if (!hasIntersectionObserver && value === modeType.observer) {
        value = modeType.event;
      }
      setMode(value);
    };
    toSetMode(observer ? modeType.observer : modeType.event);
  }, [observer]);
  return /* @__PURE__ */ React.createElement(React.Fragment, null, mode === modeType.event ? /* @__PURE__ */ React.createElement(LazyloadEvent, _extends({}, resetProps, eventOptions)) : mode === modeType.observer ? /* @__PURE__ */ React.createElement(LazyLoadObserve, resetProps) : null);
};
Lazyload.defaultProps = {
  loading: null,
  height: 0,
  observer: true
};
var stdin_default = Lazyload;
export {
  stdin_default as default
};
